==> bitfront-library-6.3.0.tgz: package/src/app/base/component/store/base-list.component.ts <==
import { ActivatedRoute } from "@angular/router";
import { Store } from "@ngrx/store";
import { Observable } from "rxjs";

import { PageStatus } from "../../..//shared/global.constants";
import { BitToolbarComponent } from "../../..//shared/component/bit-toolbar.component";
import { TableViewService } from "../../..//shared/service/tableview.service";
import { BaseFilter } from "../../shared/base.filter";

import * as fromModels from "../../models";

/**
 * Componente que implementa un listado con filtro
 * T: entidad,
 * F: Filter,
 * V: Definicion de la interface del state
 */
export abstract class BaseListComponent<T, F extends BaseFilter, V> {
  breadcrumb: any[] = [];
  items$: Observable<T[]>;
  totalItems$: Observable<number>;
  status$: Observable<PageStatus>;
  toolbar$: Observable<{}>;
  filter: F;

  protected customToolbarActions: any = {};

  constructor(
    protected store: Store<V>,
    protected tableViewService: TableViewService,
    protected activatedRoute: ActivatedRoute,
    protected factoryCreateAction: fromModels.FactoryCreateAction
  ) {}

  /** Tenemos que ver si activamos la autobúsqueda entre otras cosas */
  ngOnInit() {
    console.log("ngOnInit called");
    let query = this.activatedRoute.snapshot.params["query"];
    console.log(`parametro query con valor ${query}`);
    if (query == "true") {
      this.search(this.filter);
    }
  }

  /** el componente toolbar nos comunica que se ha pulsado un botón */
  onToolbarButtonPressed(button: string) {
    console.log("Button pressed:" + button);
    if (this.customToolbarActions[button]) {
      this.customToolbarActions[button]();
    } else if (button === BitToolbarComponent.PRINT_BUTTON) {
      this.handlePrint();
    } else if (button === BitToolbarComponent.EXPORT_BUTTON) {
      this.handleExport();
    } else if (button === BitToolbarComponent.NEW_BUTTON) {
      this.handleNew();
    } else {
      this.otherAction(button);
    }
  }

  /** el componente toolbar nos comunica que se ha pulsado un botón */
  handlePrint() {
    window.print();
  }

  /** Cuando tenemos que exportar el listado */
  handleExport() {
    if (this.tableViewService) {
      this.tableViewService.sendExportMessage(); //enviamos un mensaje a un observable para que el tableview active el export
    } else {
      alert("Exportació no implementada per aquest llistat");
    }
  }

  /** Cuando tenemos que nagevar al formulario para crear un nuevo elemento*/
  handleNew() {
    this.gotoForm();
  }

  /**cualquier otra accion que no sea la típica de guardar o eliminar */
  otherAction(button: string): void {
    console.warn(`otherAction ${button} pressed`);
  }

  /** Se invocará cuando el componente paginator hijo nos comunique que el usuario ha cambiado el número de elementos a mostrar por página */
  onNewPageSize(pageSize: number): void {
    console.log(`onNewPageSize ${pageSize}`);
    this.filter.pagina = 1; // reseteamos a la página inicial para evitar comportamienos extraños
    this.filter.resultados = pageSize;
    this.store.dispatch(this.factoryCreateAction(fromModels.GENERIC_TYPE.NEW_PAGE_SIZE, this.filter));
  }

  /** Se invocará cuando el componente paginator hijo nos comunique que el usuario ha cambiado el número de página a mostrar */
  onPageChange(page: number): void {
    console.log(`onPageChange ${page}`);
    this.filter.pagina = page;
    this.store.dispatch(this.factoryCreateAction(fromModels.GENERIC_TYPE.PAGE_CHANGE, this.filter));
  }

  search(filter: F) {
    console.log(`search called ${filter}`);
    this.store.dispatch(this.factoryCreateAction(fromModels.GENERIC_TYPE.LOAD_ITEMS, this.filter));
  }

  reset(filter: F) {
    console.log(`reset called ${filter}`);
    this.store.dispatch(this.factoryCreateAction(fromModels.GENERIC_TYPE.RESET_FILTER, this.filter));
  }

  /** No sabemos a este nivel como navegar al formulario. Es mejor que el componente lo implemente */
  abstract gotoForm(data?: any);
}

==> bitfront-library-6.6.2.tgz: package/src/app/base/component/store/base-list.component.ts <==
import { ActivatedRoute } from "@angular/router";
import { Store } from "@ngrx/store";
import { Observable } from "rxjs";

import { PageStatus } from "../../../shared/global.constants";
import { BitToolbarComponent } from "../../..//shared/component/bit-toolbar.component";
import { TableViewService } from "../../..//shared/service/tableview.service";
import { BaseFilter } from "../../shared/base.filter";

import * as fromModels from "../../models";
import { BaseComponent } from "./base.component";

/**
 * Componente que implementa un listado con filtro
 * T: entidad,
 * F: Filter,
 * V: Definicion de la interface del state
 */
export abstract class BaseListComponent<T, F extends BaseFilter, V> extends BaseComponent<V> {
  breadcrumb: any[] = [];
  items$: Observable<T[]>;
  totalItems$: Observable<number>;
  status$: Observable<PageStatus>;
  toolbar$: Observable<{}>;
  filter: F;

  protected customToolbarActions: any = {};

  constructor(
    protected store: Store<V>,
    protected tableViewService: TableViewService,
    protected activatedRoute: ActivatedRoute,
    protected factoryCreateAction: fromModels.FactoryCreateAction
  ) {
    super(store);
  }

  /** Tenemos que ver si activamos la autobúsqueda entre otras cosas */
  ngOnInit() {
    console.log("ngOnInit called");
    let query = this.activatedRoute.snapshot.params["query"];
    console.log(`parametro query con valor ${query}`);
    if (query == "true") {
      this.search(this.filter);
    }
  }

  ngOnDestroy() {
    super.ngOnDestroy();
  }

  /** el componente toolbar nos comunica que se ha pulsado un botón */
  onToolbarButtonPressed(button: string) {
    console.log("Button pressed:" + button);
    if (this.customToolbarActions[button]) {
      this.customToolbarActions[button]();
    } else if (button === BitToolbarComponent.PRINT_BUTTON) {
      this.handlePrint();
    } else if (button === BitToolbarComponent.EXPORT_BUTTON) {
      this.handleExport();
    } else if (button === BitToolbarComponent.NEW_BUTTON) {
      this.handleNew();
    } else {
      this.otherAction(button);
    }
  }

  /** el componente toolbar nos comunica que se ha pulsado un botón */
  handlePrint() {
    window.print();
  }

  /** Cuando tenemos que exportar el listado */
  handleExport() {
    if (this.tableViewService) {
      this.tableViewService.sendExportMessage(); //enviamos un mensaje a un observable para que el tableview active el export
    } else {
      alert("Exportació no implementada per aquest llistat");
    }
  }

  /** Cuando tenemos que nagevar al formulario para crear un nuevo elemento*/
  handleNew() {
    this.gotoForm();
  }

  /**cualquier otra accion que no sea la típica de guardar o eliminar */
  otherAction(button: string): void {
    console.warn(`otherAction ${button} pressed`);
  }

  /** Se invocará cuando el componente paginator hijo nos comunique que el usuario ha cambiado el número de elementos a mostrar por página */
  onNewPageSize(pageSize: number): void {
    console.log(`onNewPageSize ${pageSize}`);
    this.filter.pagina = 1; // reseteamos a la página inicial para evitar comportamienos extraños
    this.filter.resultados = pageSize;
    this.store.dispatch(this.factoryCreateAction(fromModels.GENERIC_TYPE.NEW_PAGE_SIZE, this.filter));
  }

  /** Se invocará cuando el componente paginator hijo nos comunique que el usuario ha cambiado el número de página a mostrar */
  onPageChange(page: number): void {
    console.log(`onPageChange ${page}`);
    this.filter.pagina = page;
    this.store.dispatch(this.factoryCreateAction(fromModels.GENERIC_TYPE.PAGE_CHANGE, this.filter));
  }

  search(filter: F) {
    console.log(`search called ${filter}`);
    this.store.dispatch(this.factoryCreateAction(fromModels.GENERIC_TYPE.LOAD_ITEMS, this.filter));
  }

  reset(filter: F) {
    console.log(`reset called ${filter}`);
    this.store.dispatch(this.factoryCreateAction(fromModels.GENERIC_TYPE.RESET_FILTER, this.filter));
  }

  /** No sabemos a este nivel como navegar al formulario. Es mejor que el componente lo implemente */
  abstract gotoForm(data?: any);
}
